#!/usr/bin/env python
# ----------------------------------------------------------------------------
#
# cocos_player.py
# By Ahik Man
#
# based on pyglet media_player.py example by Alex Holkner
#  you can find it and more info at: http://pyglet.org/
#
# THIS IS AN EXPERIMENTAL SOFTWARE. USE IT BY YOUR OWN RISK.
#

'''Experimental audio and video player with cucos2d GUI controls.'''

import sys
import os

from pyglet import image, media, font
from pyglet.gl import *
from pyglet.event import EventDispatcher
from pyglet.window import key

from cocos.director import director
from cocos.scene import Scene
from cocos.layer import Layer
from cocos.sprite import Sprite


class VideoLayer(Layer):
    is_event_handler=True
    def __init__(self, filename):
        super(VideoLayer, self).__init__()

        # init the media player
        self.player = media.Player()
        source = media.load(filename)
        self.player.queue(source)

        self.player.push_handlers(self)
        self.player.eos_action = self.player.EOS_PAUSE
        self.width, self.height = self.get_video_size()

        # Create empty image for the Sprite
        from pyglet.image import AbstractImage, Texture
        absImage = AbstractImage(int(self.width), int(self.height))
        # Video size might be float. Texture need int sizes
        texture = Texture(int(self.width), int(self.height), absImage, 4444)
        self.sprite = Sprite(texture)
        self.add(self.sprite)
        x,y = director.get_window_size()
        self.sprite.position =x/2, y/2

    def on_play_pause(self):
        if self.player.playing:
            self.player.pause()
        else:
            self.player.play()

    def on_key_press(self, symbol, mod):
        if symbol == key.SPACE:
            self.on_play_pause()
        if symbol == key.Q:
            self.player.pause() # Avoid annoying noise
            pyglet.app.exit()

    def get_video_size(self):
        if not self.player.source or not self.player.source.video_format:
            print "Oops. No source or no video..."
            return
        video_format = self.player.source.video_format
        width = video_format.width
        height = video_format.height
        if video_format.sample_aspect > 1:
            width *= video_format.sample_aspect
        elif video_format.sample_aspect < 1:
            height /= video_format.sample_aspect
        return width, height

    def draw(self):
        if self.player.source and self.player.source.video_format:
            self.sprite._set_texture(self.player.texture)

if __name__ == "__main__":
    if len(sys.argv) < 2:
        print 'Usage: cocosPlayer.py <filename>'
        sys.exit(1)
    filename = sys.argv[1]

    # arrange the cocos scene
    director.init(width=1024, height=768, resizable=False)

    vl = VideoLayer(filename)
    scene = Scene(vl)

    # Let the scene build first (trying avoid annoying sounds)
    vl.player.play()
    director.run(scene)
